from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ShdataCls:
	"""Shdata commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("shdata", core, parent)

	def set(self, short_frame_data: str, commandBlock=repcap.CommandBlock.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NFC:CBLock<CH>:APGeneric:SHData \n
		Snippet: driver.source.bb.nfc.cblock.apGeneric.shdata.set(short_frame_data = rawAbc, commandBlock = repcap.CommandBlock.Default) \n
		Sets the data bits of a short frame. \n
			:param short_frame_data: integer
			:param commandBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')
		"""
		param = Conversions.value_to_str(short_frame_data)
		commandBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(commandBlock, repcap.CommandBlock)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:CBLock{commandBlock_cmd_val}:APGeneric:SHData {param}')

	def get(self, commandBlock=repcap.CommandBlock.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:NFC:CBLock<CH>:APGeneric:SHData \n
		Snippet: value: str = driver.source.bb.nfc.cblock.apGeneric.shdata.get(commandBlock = repcap.CommandBlock.Default) \n
		Sets the data bits of a short frame. \n
			:param commandBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')
			:return: short_frame_data: integer"""
		commandBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(commandBlock, repcap.CommandBlock)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NFC:CBLock{commandBlock_cmd_val}:APGeneric:SHData?')
		return trim_str_response(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CcodingCls:
	"""Ccoding commands group definition. 9 total commands, 9 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ccoding", core, parent)

	@property
	def mib(self):
		"""mib commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mib'):
			from .Mib import MibCls
			self._mib = MibCls(self._core, self._cmd_group)
		return self._mib

	@property
	def mspare(self):
		"""mspare commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mspare'):
			from .Mspare import MspareCls
			self._mspare = MspareCls(self._core, self._cmd_group)
		return self._mspare

	@property
	def rsib(self):
		"""rsib commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rsib'):
			from .Rsib import RsibCls
			self._rsib = RsibCls(self._core, self._cmd_group)
		return self._rsib

	@property
	def sib(self):
		"""sib commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sib'):
			from .Sib import SibCls
			self._sib = SibCls(self._core, self._cmd_group)
		return self._sib

	@property
	def soffset(self):
		"""soffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_soffset'):
			from .Soffset import SoffsetCls
			self._soffset = SoffsetCls(self._core, self._cmd_group)
		return self._soffset

	@property
	def srPeriod(self):
		"""srPeriod commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_srPeriod'):
			from .SrPeriod import SrPeriodCls
			self._srPeriod = SrPeriodCls(self._core, self._cmd_group)
		return self._srPeriod

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def tbsi(self):
		"""tbsi commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tbsi'):
			from .Tbsi import TbsiCls
			self._tbsi = TbsiCls(self._core, self._cmd_group)
		return self._tbsi

	@property
	def tbSize(self):
		"""tbSize commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tbSize'):
			from .TbSize import TbSizeCls
			self._tbSize = TbSizeCls(self._core, self._cmd_group)
		return self._tbSize

	def clone(self) -> 'CcodingCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CcodingCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal.Types import DataType
from .........Internal.StructBase import StructBase
from .........Internal.ArgStruct import ArgStruct
from .........Internal.ArgSingleList import ArgSingleList
from .........Internal.ArgSingle import ArgSingle
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SfbmpCls:
	"""Sfbmp commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sfbmp", core, parent)

	def set(self, pattern: str, bitcount: int, userEquipment=repcap.UserEquipment.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:SL:RDATa:SFBMp \n
		Snippet: driver.source.bb.eutra.uplink.ue.sl.rdata.sfbmp.set(pattern = rawAbc, bitcount = 1, userEquipment = repcap.UserEquipment.Default) \n
		Sets the subframe bitmap. \n
			:param pattern: numeric
			:param bitcount: integer Range: 1 to 42
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('pattern', pattern, DataType.RawString), ArgSingle('bitcount', bitcount, DataType.Integer))
		userEquipment_cmd_val = self._cmd_group.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:SL:RDATa:SFBMp {param}'.rstrip())

	# noinspection PyTypeChecker
	class SfbmpStruct(StructBase):
		"""Response structure. Fields: \n
			- Pattern: str: numeric
			- Bitcount: int: integer Range: 1 to 42"""
		__meta_args_list = [
			ArgStruct.scalar_raw_str('Pattern'),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Pattern: str = None
			self.Bitcount: int = None

	def get(self, userEquipment=repcap.UserEquipment.Default) -> SfbmpStruct:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:SL:RDATa:SFBMp \n
		Snippet: value: SfbmpStruct = driver.source.bb.eutra.uplink.ue.sl.rdata.sfbmp.get(userEquipment = repcap.UserEquipment.Default) \n
		Sets the subframe bitmap. \n
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:return: structure: for return value, see the help for SfbmpStruct structure arguments."""
		userEquipment_cmd_val = self._cmd_group.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:SL:RDATa:SFBMp?', self.__class__.SfbmpStruct())



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EvdoCls:
	"""Evdo commands group definition. 154 total commands, 13 Subgroups, 8 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("evdo", core, parent)

	@property
	def anetwork(self):
		"""anetwork commands group. 3 Sub-classes, 3 commands."""
		if not hasattr(self, '_anetwork'):
			from .Anetwork import AnetworkCls
			self._anetwork = AnetworkCls(self._core, self._cmd_group)
		return self._anetwork

	@property
	def clipping(self):
		"""clipping commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_clipping'):
			from .Clipping import ClippingCls
			self._clipping = ClippingCls(self._core, self._cmd_group)
		return self._clipping

	@property
	def clock(self):
		"""clock commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_clock'):
			from .Clock import ClockCls
			self._clock = ClockCls(self._core, self._cmd_group)
		return self._clock

	@property
	def crate(self):
		"""crate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_crate'):
			from .Crate import CrateCls
			self._crate = CrateCls(self._core, self._cmd_group)
		return self._crate

	@property
	def down(self):
		"""down commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_down'):
			from .Down import DownCls
			self._down = DownCls(self._core, self._cmd_group)
		return self._down

	@property
	def filterPy(self):
		"""filterPy commands group. 3 Sub-classes, 2 commands."""
		if not hasattr(self, '_filterPy'):
			from .FilterPy import FilterPyCls
			self._filterPy = FilterPyCls(self._core, self._cmd_group)
		return self._filterPy

	@property
	def iqswap(self):
		"""iqswap commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_iqswap'):
			from .Iqswap import IqswapCls
			self._iqswap = IqswapCls(self._core, self._cmd_group)
		return self._iqswap

	@property
	def setting(self):
		"""setting commands group. 0 Sub-classes, 4 commands."""
		if not hasattr(self, '_setting'):
			from .Setting import SettingCls
			self._setting = SettingCls(self._core, self._cmd_group)
		return self._setting

	@property
	def terminal(self):
		"""terminal commands group. 15 Sub-classes, 0 commands."""
		if not hasattr(self, '_terminal'):
			from .Terminal import TerminalCls
			self._terminal = TerminalCls(self._core, self._cmd_group)
		return self._terminal

	@property
	def trigger(self):
		"""trigger commands group. 5 Sub-classes, 5 commands."""
		if not hasattr(self, '_trigger'):
			from .Trigger import TriggerCls
			self._trigger = TriggerCls(self._core, self._cmd_group)
		return self._trigger

	@property
	def up(self):
		"""up commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_up'):
			from .Up import UpCls
			self._up = UpCls(self._core, self._cmd_group)
		return self._up

	@property
	def user(self):
		"""user commands group. 11 Sub-classes, 0 commands."""
		if not hasattr(self, '_user'):
			from .User import UserCls
			self._user = UserCls(self._core, self._cmd_group)
		return self._user

	@property
	def waveform(self):
		"""waveform commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_waveform'):
			from .Waveform import WaveformCls
			self._waveform = WaveformCls(self._core, self._cmd_group)
		return self._waveform

	# noinspection PyTypeChecker
	def get_link(self) -> enums.LinkDir:
		"""SCPI: [SOURce<HW>]:BB:EVDO:LINK \n
		Snippet: value: enums.LinkDir = driver.source.bb.evdo.get_link() \n
		Defines the transmission direction. \n
			:return: link: FORWard/DOWN | REVerse/UP
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EVDO:LINK?')
		return Conversions.str_to_scalar_enum(response, enums.LinkDir)

	def set_link(self, link: enums.LinkDir) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:LINK \n
		Snippet: driver.source.bb.evdo.set_link(link = enums.LinkDir.DOWN) \n
		Defines the transmission direction. \n
			:param link: FORWard/DOWN | REVerse/UP
		"""
		param = Conversions.enum_scalar_to_str(link, enums.LinkDir)
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:LINK {param}')

	def get_pn_offset(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EVDO:PNOFfset \n
		Snippet: value: int = driver.source.bb.evdo.get_pn_offset() \n
		Sets the PN Offset of the 1xEV-DO signal. \n
			:return: pn_offset: integer Range: 0 to 511
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EVDO:PNOFfset?')
		return Conversions.str_to_int(response)

	def set_pn_offset(self, pn_offset: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:PNOFfset \n
		Snippet: driver.source.bb.evdo.set_pn_offset(pn_offset = 1) \n
		Sets the PN Offset of the 1xEV-DO signal. \n
			:param pn_offset: integer Range: 0 to 511
		"""
		param = Conversions.decimal_value_to_str(pn_offset)
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:PNOFfset {param}')

	# noinspection PyTypeChecker
	def get_predefined(self) -> enums.EvdoPredSett:
		"""SCPI: [SOURce<HW>]:BB:EVDO:PREDefined \n
		Snippet: value: enums.EvdoPredSett = driver.source.bb.evdo.get_predefined() \n
		Sets the UL setting of Terminal 1 to one of the predefined configurations. The predefined settings are made according to
		3GPP2 C.S0032-A to allow easy receiver testing.
			Table Header: Parameter / Description \n
			- USER / There are no predefined settings
			- ULS1DR9K6 / UL, Subtype 1, 9.6 kbps.
			- ULS1DR19K2 / UL, Subtype 1, 19.2 kbps.
			- ULS1DR38K4 / UL, Subtype 1, 38.4 kbps.
			- ULS1DR76K8 / UL, Subtype 1, 76.8 kbps.
			- ULS1DR153K6 / UL, Subtype 1, 153.6 kbps.
			- ULS2PS128LL / UL, Subtype 2, 128 bits payload, Low Latency.
			- ULS2PS256HC / UL, Subtype 2, 256 bits payload, High Capacity.
			- ULS2PS256LL / UL, Subtype 2, 256 bits payload, Low Latency.
			- ULS2PS512LL / UL, Subtype 2, 512 bits payload, Low Latency.
			- ULS2PS768LL / UL, Subtype 2, 768 bits payload, Low Latency.
			- ULS2PS1024LL / UL, Subtype 2, 1024 bits payload, Low Latency.
			- ULS2PS1536LL / UL, Subtype 2, 1536 bits payload, Low Latency.
			- ULS2PS2048LL / UL, Subtype 2, 2048 bits payload, Low Latency.
			- ULS2PS3072LL / UL, Subtype 2, 3072 bits payload, Low Latency.
			- ULS2PS4096LL / UL, Subtype 2, 4096 bits payload, Low Latency.
			- ULS2PS6144LL / UL, Subtype 2, 6144 bits payload, Low Latency.
			- ULS2PS8192LL / UL, Subtype 2, 8192 bits payload, Low Latency.
			- ULS2PS12288LL / UL, Subtype 2, 12288 bits payload, Low Latency. \n
			:return: predefined: USER| ULS1DR9K6| ULS1DR19K2| ULS1DR38K4| ULS1DR76K8| ULS1DR153K6| ULS2PS128LL| ULS2PS256HC| ULS2PS256LL| ULS2PS512LL| ULS2PS768LL| ULS2PS1024LL| ULS2PS1536LL| ULS2PS2048LL| ULS2PS3072LL| ULS2PS4096LL| ULS2PS6144LL| ULS2PS8192LL| ULS2PS12288LL
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EVDO:PREDefined?')
		return Conversions.str_to_scalar_enum(response, enums.EvdoPredSett)

	def set_predefined(self, predefined: enums.EvdoPredSett) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:PREDefined \n
		Snippet: driver.source.bb.evdo.set_predefined(predefined = enums.EvdoPredSett.ULS1DR153K6) \n
		Sets the UL setting of Terminal 1 to one of the predefined configurations. The predefined settings are made according to
		3GPP2 C.S0032-A to allow easy receiver testing.
			Table Header: Parameter / Description \n
			- USER / There are no predefined settings
			- ULS1DR9K6 / UL, Subtype 1, 9.6 kbps.
			- ULS1DR19K2 / UL, Subtype 1, 19.2 kbps.
			- ULS1DR38K4 / UL, Subtype 1, 38.4 kbps.
			- ULS1DR76K8 / UL, Subtype 1, 76.8 kbps.
			- ULS1DR153K6 / UL, Subtype 1, 153.6 kbps.
			- ULS2PS128LL / UL, Subtype 2, 128 bits payload, Low Latency.
			- ULS2PS256HC / UL, Subtype 2, 256 bits payload, High Capacity.
			- ULS2PS256LL / UL, Subtype 2, 256 bits payload, Low Latency.
			- ULS2PS512LL / UL, Subtype 2, 512 bits payload, Low Latency.
			- ULS2PS768LL / UL, Subtype 2, 768 bits payload, Low Latency.
			- ULS2PS1024LL / UL, Subtype 2, 1024 bits payload, Low Latency.
			- ULS2PS1536LL / UL, Subtype 2, 1536 bits payload, Low Latency.
			- ULS2PS2048LL / UL, Subtype 2, 2048 bits payload, Low Latency.
			- ULS2PS3072LL / UL, Subtype 2, 3072 bits payload, Low Latency.
			- ULS2PS4096LL / UL, Subtype 2, 4096 bits payload, Low Latency.
			- ULS2PS6144LL / UL, Subtype 2, 6144 bits payload, Low Latency.
			- ULS2PS8192LL / UL, Subtype 2, 8192 bits payload, Low Latency.
			- ULS2PS12288LL / UL, Subtype 2, 12288 bits payload, Low Latency. \n
			:param predefined: USER| ULS1DR9K6| ULS1DR19K2| ULS1DR38K4| ULS1DR76K8| ULS1DR153K6| ULS2PS128LL| ULS2PS256HC| ULS2PS256LL| ULS2PS512LL| ULS2PS768LL| ULS2PS1024LL| ULS2PS1536LL| ULS2PS2048LL| ULS2PS3072LL| ULS2PS4096LL| ULS2PS6144LL| ULS2PS8192LL| ULS2PS12288LL
		"""
		param = Conversions.enum_scalar_to_str(predefined, enums.EvdoPredSett)
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:PREDefined {param}')

	def preset(self) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:PRESet \n
		Snippet: driver.source.bb.evdo.preset() \n
		Sets the parameters of the digital standard to their default values (*RST values specified for the commands) .
		Not affected is the state set with the command SOURce<hw>:BB:EVDO:STATe. \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:PRESet')

	def preset_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:PRESet \n
		Snippet: driver.source.bb.evdo.preset_with_opc() \n
		Sets the parameters of the digital standard to their default values (*RST values specified for the commands) .
		Not affected is the state set with the command SOURce<hw>:BB:EVDO:STATe. \n
		Same as preset, but waits for the operation to complete before continuing further. Use the RsSmbv.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:BB:EVDO:PRESet', opc_timeout_ms)

	def get_slength(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EVDO:SLENgth \n
		Snippet: value: int = driver.source.bb.evdo.get_slength() \n
		(For reverse link mode only) Sets the sequence length of the arbitrary waveform component of the 1XEV-DO signal in number
		of frames. This component is calculated in advance and output in the arbitrary waveform generator. It is added to the
		real time signal components. The number of chips is determined from this sequence length. One slot of 1.67ms duration
		equals 2048 chips. \n
			:return: slength: integer Range: 4 to dynamic
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EVDO:SLENgth?')
		return Conversions.str_to_int(response)

	def set_slength(self, slength: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:SLENgth \n
		Snippet: driver.source.bb.evdo.set_slength(slength = 1) \n
		(For reverse link mode only) Sets the sequence length of the arbitrary waveform component of the 1XEV-DO signal in number
		of frames. This component is calculated in advance and output in the arbitrary waveform generator. It is added to the
		real time signal components. The number of chips is determined from this sequence length. One slot of 1.67ms duration
		equals 2048 chips. \n
			:param slength: integer Range: 4 to dynamic
		"""
		param = Conversions.decimal_value_to_str(slength)
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:SLENgth {param}')

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:EVDO:STATe \n
		Snippet: value: bool = driver.source.bb.evdo.get_state() \n
		Activates the standard and deactivates all the other digital standards and digital modulation modes in the same path. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EVDO:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:STATe \n
		Snippet: driver.source.bb.evdo.set_state(state = False) \n
		Activates the standard and deactivates all the other digital standards and digital modulation modes in the same path. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:STATe {param}')

	def get_stime(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:EVDO:STIMe \n
		Snippet: value: int = driver.source.bb.evdo.get_stime() \n
		Sets the System Time value of the 1xEV-DO signal and the base station. The System Time value is expressed in units of 1.
		67 ms intervals (80 ms/ 48) . Note: In uplink, the value selected for system time must be multiple of 16. \n
			:return: stime: integer Range: 0 to 2199023255551
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EVDO:STIMe?')
		return Conversions.str_to_int(response)

	def set_stime(self, stime: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:EVDO:STIMe \n
		Snippet: driver.source.bb.evdo.set_stime(stime = 1) \n
		Sets the System Time value of the 1xEV-DO signal and the base station. The System Time value is expressed in units of 1.
		67 ms intervals (80 ms/ 48) . Note: In uplink, the value selected for system time must be multiple of 16. \n
			:param stime: integer Range: 0 to 2199023255551
		"""
		param = Conversions.decimal_value_to_str(stime)
		self._core.io.write(f'SOURce<HwInstance>:BB:EVDO:STIMe {param}')

	def get_version(self) -> str:
		"""SCPI: [SOURce<HW>]:BB:EVDO:VERSion \n
		Snippet: value: str = driver.source.bb.evdo.get_version() \n
		Queries the version of the 1xEV-DO standard underlying the definitions \n
			:return: version: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:EVDO:VERSion?')
		return trim_str_response(response)

	def clone(self) -> 'EvdoCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = EvdoCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EsCls:
	"""Es commands group definition. 7 total commands, 2 Subgroups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("es", core, parent)

	@property
	def cs(self):
		"""cs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cs'):
			from .Cs import CsCls
			self._cs = CsCls(self._core, self._cmd_group)
		return self._cs

	@property
	def tp(self):
		"""tp commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tp'):
			from .Tp import TpCls
			self._tp = TpCls(self._core, self._cmd_group)
		return self._tp

	def get_cs_length(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:ES:CSLength \n
		Snippet: value: int = driver.source.bb.nr5G.qckset.general.es.get_cs_length() \n
		Sets the number of symbols in the CORESET. \n
			:return: qck_set_corset_len: integer Range: 1 to 3
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:ES:CSLength?')
		return Conversions.str_to_int(response)

	def set_cs_length(self, qck_set_corset_len: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:ES:CSLength \n
		Snippet: driver.source.bb.nr5G.qckset.general.es.set_cs_length(qck_set_corset_len = 1) \n
		Sets the number of symbols in the CORESET. \n
			:param qck_set_corset_len: integer Range: 1 to 3
		"""
		param = Conversions.decimal_value_to_str(qck_set_corset_len)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:ES:CSLength {param}')

	# noinspection PyTypeChecker
	def get_mod(self) -> enums.QckSettingsModType:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:ES:MOD \n
		Snippet: value: enums.QckSettingsModType = driver.source.bb.nr5G.qckset.general.es.get_mod() \n
		Sets the modulation scheme. \n
			:return: qck_set_mod_type: QPSK| QAM16| QAM64| QAM256| BPSK2| QAM1024
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:ES:MOD?')
		return Conversions.str_to_scalar_enum(response, enums.QckSettingsModType)

	def set_mod(self, qck_set_mod_type: enums.QckSettingsModType) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:ES:MOD \n
		Snippet: driver.source.bb.nr5G.qckset.general.es.set_mod(qck_set_mod_type = enums.QckSettingsModType.BPSK2) \n
		Sets the modulation scheme. \n
			:param qck_set_mod_type: QPSK| QAM16| QAM64| QAM256| BPSK2| QAM1024
		"""
		param = Conversions.enum_scalar_to_str(qck_set_mod_type, enums.QckSettingsModType)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:ES:MOD {param}')

	# noinspection PyTypeChecker
	def get_rb_config(self) -> enums.Config:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:ES:RBConfig \n
		Snippet: value: enums.Config = driver.source.bb.nr5G.qckset.general.es.get_rb_config() \n
		Sets the configuration mode for the resource block configuration. \n
			:return: qck_set_rb_config: MAN| EFL| EFR| ERL| ERR| OUTF| INNF| I1RL| I1RR| OUTP| O1RL| O1RR| R1IF| R1IL| R1IR| R2IF| R2IL| R2IR
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:ES:RBConfig?')
		return Conversions.str_to_scalar_enum(response, enums.Config)

	def set_rb_config(self, qck_set_rb_config: enums.Config) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:ES:RBConfig \n
		Snippet: driver.source.bb.nr5G.qckset.general.es.set_rb_config(qck_set_rb_config = enums.Config.EFL) \n
		Sets the configuration mode for the resource block configuration. \n
			:param qck_set_rb_config: MAN| EFL| EFR| ERL| ERR| OUTF| INNF| I1RL| I1RR| OUTP| O1RL| O1RR| R1IF| R1IL| R1IR| R2IF| R2IL| R2IR
		"""
		param = Conversions.enum_scalar_to_str(qck_set_rb_config, enums.Config)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:ES:RBConfig {param}')

	def get_rb_number(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:ES:RBNumber \n
		Snippet: value: int = driver.source.bb.nr5G.qckset.general.es.get_rb_number() \n
		Sets the number of resource blocks. \n
			:return: qck_set_rb_num: integer Range: 1 to 273
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:ES:RBNumber?')
		return Conversions.str_to_int(response)

	def set_rb_number(self, qck_set_rb_num: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:ES:RBNumber \n
		Snippet: driver.source.bb.nr5G.qckset.general.es.set_rb_number(qck_set_rb_num = 1) \n
		Sets the number of resource blocks. \n
			:param qck_set_rb_num: integer Range: 1 to 273
		"""
		param = Conversions.decimal_value_to_str(qck_set_rb_num)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:ES:RBNumber {param}')

	def get_rb_offset(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:ES:RBOFfset \n
		Snippet: value: int = driver.source.bb.nr5G.qckset.general.es.get_rb_offset() \n
		Sets the resource block offset. \n
			:return: qck_set_rb_offset: integer Range: 0 to 272
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:ES:RBOFfset?')
		return Conversions.str_to_int(response)

	def set_rb_offset(self, qck_set_rb_offset: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:QCKSet:GENeral:ES:RBOFfset \n
		Snippet: driver.source.bb.nr5G.qckset.general.es.set_rb_offset(qck_set_rb_offset = 1) \n
		Sets the resource block offset. \n
			:param qck_set_rb_offset: integer Range: 0 to 272
		"""
		param = Conversions.decimal_value_to_str(qck_set_rb_offset)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:QCKSet:GENeral:ES:RBOFfset {param}')

	def clone(self) -> 'EsCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = EsCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ..............Internal.Core import Core
from ..............Internal.CommandsGroup import CommandsGroup
from ..............Internal import Conversions
from .............. import enums
from .............. import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PerCls:
	"""Per commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("per", core, parent)

	def set(self, srs_rs_periodicit: enums.SrsRsPeriodicityAll, userNull=repcap.UserNull.Default, cellNull=repcap.CellNull.Default, bwPartNull=repcap.BwPartNull.Default, resourceSetNull=repcap.ResourceSetNull.Default, resourceNull=repcap.ResourceNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<US(CH0)>:CELL<CC(ST0)>:UL:BWP<BWP(DIR0)>:SRS:RS:SET<GR0>:RES<USER0>:PER \n
		Snippet: driver.source.bb.nr5G.ubwp.user.cell.uplink.bwp.srs.rs.set.res.per.set(srs_rs_periodicit = enums.SrsRsPeriodicityAll.SL1, userNull = repcap.UserNull.Default, cellNull = repcap.CellNull.Default, bwPartNull = repcap.BwPartNull.Default, resourceSetNull = repcap.ResourceSetNull.Default, resourceNull = repcap.ResourceNull.Default) \n
		Sets the SRS repetition factor. \n
			:param srs_rs_periodicit: SL1| SL2| SL4| SL5| SL8| SL10| SL16| SL20| SL32| SL40| SL64| SL80| SL160| SL320| SL640| SL1280| SL2560| SL81920| SL40960| SL10240| SL5120
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Bwp')
			:param resourceSetNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Set')
			:param resourceNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Res')
		"""
		param = Conversions.enum_scalar_to_str(srs_rs_periodicit, enums.SrsRsPeriodicityAll)
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		resourceSetNull_cmd_val = self._cmd_group.get_repcap_cmd_value(resourceSetNull, repcap.ResourceSetNull)
		resourceNull_cmd_val = self._cmd_group.get_repcap_cmd_value(resourceNull, repcap.ResourceNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:CELL{cellNull_cmd_val}:UL:BWP{bwPartNull_cmd_val}:SRS:RS:SET{resourceSetNull_cmd_val}:RES{resourceNull_cmd_val}:PER {param}')

	# noinspection PyTypeChecker
	def get(self, userNull=repcap.UserNull.Default, cellNull=repcap.CellNull.Default, bwPartNull=repcap.BwPartNull.Default, resourceSetNull=repcap.ResourceSetNull.Default, resourceNull=repcap.ResourceNull.Default) -> enums.SrsRsPeriodicityAll:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<US(CH0)>:CELL<CC(ST0)>:UL:BWP<BWP(DIR0)>:SRS:RS:SET<GR0>:RES<USER0>:PER \n
		Snippet: value: enums.SrsRsPeriodicityAll = driver.source.bb.nr5G.ubwp.user.cell.uplink.bwp.srs.rs.set.res.per.get(userNull = repcap.UserNull.Default, cellNull = repcap.CellNull.Default, bwPartNull = repcap.BwPartNull.Default, resourceSetNull = repcap.ResourceSetNull.Default, resourceNull = repcap.ResourceNull.Default) \n
		Sets the SRS repetition factor. \n
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Bwp')
			:param resourceSetNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Set')
			:param resourceNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Res')
			:return: srs_rs_periodicit: SL1| SL2| SL4| SL5| SL8| SL10| SL16| SL20| SL32| SL40| SL64| SL80| SL160| SL320| SL640| SL1280| SL2560| SL81920| SL40960| SL10240| SL5120"""
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		resourceSetNull_cmd_val = self._cmd_group.get_repcap_cmd_value(resourceSetNull, repcap.ResourceSetNull)
		resourceNull_cmd_val = self._cmd_group.get_repcap_cmd_value(resourceNull, repcap.ResourceNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:CELL{cellNull_cmd_val}:UL:BWP{bwPartNull_cmd_val}:SRS:RS:SET{resourceSetNull_cmd_val}:RES{resourceNull_cmd_val}:PER?')
		return Conversions.str_to_scalar_enum(response, enums.SrsRsPeriodicityAll)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.RepeatedCapability import RepeatedCapability
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TerminalCls:
	"""Terminal commands group definition. 52 total commands, 15 Subgroups, 0 group commands
	Repeated Capability: Terminal, default value after init: Terminal.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("terminal", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_terminal_get', 'repcap_terminal_set', repcap.Terminal.Nr1)

	def repcap_terminal_set(self, terminal: repcap.Terminal) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Terminal.Default
		Default value after init: Terminal.Nr1"""
		self._cmd_group.set_repcap_enum_value(terminal)

	def repcap_terminal_get(self) -> repcap.Terminal:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def ackChannel(self):
		"""ackChannel commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_ackChannel'):
			from .AckChannel import AckChannelCls
			self._ackChannel = AckChannelCls(self._core, self._cmd_group)
		return self._ackChannel

	@property
	def acycle(self):
		"""acycle commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_acycle'):
			from .Acycle import AcycleCls
			self._acycle = AcycleCls(self._core, self._cmd_group)
		return self._acycle

	@property
	def apChannel(self):
		"""apChannel commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_apChannel'):
			from .ApChannel import ApChannelCls
			self._apChannel = ApChannelCls(self._core, self._cmd_group)
		return self._apChannel

	@property
	def dchannel(self):
		"""dchannel commands group. 7 Sub-classes, 0 commands."""
		if not hasattr(self, '_dchannel'):
			from .Dchannel import DchannelCls
			self._dchannel = DchannelCls(self._core, self._cmd_group)
		return self._dchannel

	@property
	def dqSpreading(self):
		"""dqSpreading commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dqSpreading'):
			from .DqSpreading import DqSpreadingCls
			self._dqSpreading = DqSpreadingCls(self._core, self._cmd_group)
		return self._dqSpreading

	@property
	def drcChannel(self):
		"""drcChannel commands group. 6 Sub-classes, 0 commands."""
		if not hasattr(self, '_drcChannel'):
			from .DrcChannel import DrcChannelCls
			self._drcChannel = DrcChannelCls(self._core, self._cmd_group)
		return self._drcChannel

	@property
	def dscChannel(self):
		"""dscChannel commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_dscChannel'):
			from .DscChannel import DscChannelCls
			self._dscChannel = DscChannelCls(self._core, self._cmd_group)
		return self._dscChannel

	@property
	def imask(self):
		"""imask commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_imask'):
			from .Imask import ImaskCls
			self._imask = ImaskCls(self._core, self._cmd_group)
		return self._imask

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	@property
	def pchannel(self):
		"""pchannel commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_pchannel'):
			from .Pchannel import PchannelCls
			self._pchannel = PchannelCls(self._core, self._cmd_group)
		return self._pchannel

	@property
	def plength(self):
		"""plength commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_plength'):
			from .Plength import PlengthCls
			self._plength = PlengthCls(self._core, self._cmd_group)
		return self._plength

	@property
	def qmask(self):
		"""qmask commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_qmask'):
			from .Qmask import QmaskCls
			self._qmask = QmaskCls(self._core, self._cmd_group)
		return self._qmask

	@property
	def rriChannel(self):
		"""rriChannel commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_rriChannel'):
			from .RriChannel import RriChannelCls
			self._rriChannel = RriChannelCls(self._core, self._cmd_group)
		return self._rriChannel

	@property
	def state(self):
		"""state commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .State import StateCls
			self._state = StateCls(self._core, self._cmd_group)
		return self._state

	@property
	def subType(self):
		"""subType commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_subType'):
			from .SubType import SubTypeCls
			self._subType = SubTypeCls(self._core, self._cmd_group)
		return self._subType

	def clone(self) -> 'TerminalCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TerminalCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SpunctureCls:
	"""Spuncture commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("spuncture", core, parent)

	# noinspection PyTypeChecker
	def get(self, baseStation=repcap.BaseStation.Default, groupNull=repcap.GroupNull.Default, offset=repcap.Offset.Default) -> enums.Cdma2KchanCodSymbPunc:
		"""SCPI: [SOURce<HW>]:BB:C2K:BSTation<ST>:CGRoup<DI0>:COFFset<CH>:CCODing:SPUNcture \n
		Snippet: value: enums.Cdma2KchanCodSymbPunc = driver.source.bb.c2K.bstation.cgroup.coffset.ccoding.spuncture.get(baseStation = repcap.BaseStation.Default, groupNull = repcap.GroupNull.Default, offset = repcap.Offset.Default) \n
		The command queries the symbol puncture rate. This value is only available for channel coding modes 'Complete' and
		'Without Interleaving' (SOURce:BB:C2K:BST<n>:CGRoup<n>:COFFset<n>:CCODing:MODE COMP | NOIN) . For the traffic channels,
		this value is specific for the selected radio configuration. \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param groupNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cgroup')
			:param offset: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Coffset')
			:return: spuncture: 8OF24| 1OF5| 1OF9| 4OF12| 2OF18| 2OF6| T2OF18| T4OF12| NONE xOFy a symbol puncture rate of x out of y is used TxOFy a symbol puncture rate of x out of y Turbo is used"""
		baseStation_cmd_val = self._cmd_group.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		groupNull_cmd_val = self._cmd_group.get_repcap_cmd_value(groupNull, repcap.GroupNull)
		offset_cmd_val = self._cmd_group.get_repcap_cmd_value(offset, repcap.Offset)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:C2K:BSTation{baseStation_cmd_val}:CGRoup{groupNull_cmd_val}:COFFset{offset_cmd_val}:CCODing:SPUNcture?')
		return Conversions.str_to_scalar_enum(response, enums.Cdma2KchanCodSymbPunc)



from ............Internal.Core import Core
from ............Internal.CommandsGroup import CommandsGroup
from ............Internal.Types import DataType
from ............Internal.StructBase import StructBase
from ............Internal.ArgStruct import ArgStruct
from ............Internal.ArgSingleList import ArgSingleList
from ............Internal.ArgSingle import ArgSingle
from ............ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SltPattCls:
	"""SltPatt commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sltPatt", core, parent)

	def set(self, rate_mat_slot_patt: str, bitcount: int, userNull=repcap.UserNull.Default, cellNull=repcap.CellNull.Default, bwPartNull=repcap.BwPartNull.Default, rateSettingNull=repcap.RateSettingNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<US(CH0)>:CELL<CC(ST0)>:DL:BWP<BWP(DIR0)>:RATM:RS<GR0>:SLTPatt \n
		Snippet: driver.source.bb.nr5G.ubwp.user.cell.downlink.bwp.ratm.rs.sltPatt.set(rate_mat_slot_patt = rawAbc, bitcount = 1, userNull = repcap.UserNull.Default, cellNull = repcap.CellNull.Default, bwPartNull = repcap.BwPartNull.Default, rateSettingNull = repcap.RateSettingNull.Default) \n
		Set the slots to be used as a pattern. \n
			:param rate_mat_slot_patt: 28 bits
			:param bitcount: integer Range: 14 to 28
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Bwp')
			:param rateSettingNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Rs')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('rate_mat_slot_patt', rate_mat_slot_patt, DataType.RawString), ArgSingle('bitcount', bitcount, DataType.Integer))
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		rateSettingNull_cmd_val = self._cmd_group.get_repcap_cmd_value(rateSettingNull, repcap.RateSettingNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:CELL{cellNull_cmd_val}:DL:BWP{bwPartNull_cmd_val}:RATM:RS{rateSettingNull_cmd_val}:SLTPatt {param}'.rstrip())

	# noinspection PyTypeChecker
	class SltPattStruct(StructBase):
		"""Response structure. Fields: \n
			- Rate_Mat_Slot_Patt: str: 28 bits
			- Bitcount: int: integer Range: 14 to 28"""
		__meta_args_list = [
			ArgStruct.scalar_raw_str('Rate_Mat_Slot_Patt'),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Rate_Mat_Slot_Patt: str = None
			self.Bitcount: int = None

	def get(self, userNull=repcap.UserNull.Default, cellNull=repcap.CellNull.Default, bwPartNull=repcap.BwPartNull.Default, rateSettingNull=repcap.RateSettingNull.Default) -> SltPattStruct:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<US(CH0)>:CELL<CC(ST0)>:DL:BWP<BWP(DIR0)>:RATM:RS<GR0>:SLTPatt \n
		Snippet: value: SltPattStruct = driver.source.bb.nr5G.ubwp.user.cell.downlink.bwp.ratm.rs.sltPatt.get(userNull = repcap.UserNull.Default, cellNull = repcap.CellNull.Default, bwPartNull = repcap.BwPartNull.Default, rateSettingNull = repcap.RateSettingNull.Default) \n
		Set the slots to be used as a pattern. \n
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Bwp')
			:param rateSettingNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Rs')
			:return: structure: for return value, see the help for SltPattStruct structure arguments."""
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		rateSettingNull_cmd_val = self._cmd_group.get_repcap_cmd_value(rateSettingNull, repcap.RateSettingNull)
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:CELL{cellNull_cmd_val}:DL:BWP{bwPartNull_cmd_val}:RATM:RS{rateSettingNull_cmd_val}:SLTPatt?', self.__class__.SltPattStruct())



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, mode: enums.TdscdmaSlotModeUp, cell=repcap.Cell.Default, slotNull=repcap.SlotNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:UP:CELL<ST>:SLOT<CH0>:MODE \n
		Snippet: driver.source.bb.tdscdma.up.cell.slot.mode.set(mode = enums.TdscdmaSlotModeUp.DEDicated, cell = repcap.Cell.Default, slotNull = repcap.SlotNull.Default) \n
		Sets the mode in which the slot is to work. \n
			:param mode: DEDicated| PRACh DEDicated The instrument generates a signal with a dedicated physical control channel (DPCCH) and up to six dedicated physical data channels (DPDCH) . The signal is used for voice and data transmission. PRACh The instrument generates a single physical random access channel (PRACH) . This channel is needed to set up the connection between the mobile station and the base station.
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
			:param slotNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.TdscdmaSlotModeUp)
		cell_cmd_val = self._cmd_group.get_repcap_cmd_value(cell, repcap.Cell)
		slotNull_cmd_val = self._cmd_group.get_repcap_cmd_value(slotNull, repcap.SlotNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:TDSCdma:UP:CELL{cell_cmd_val}:SLOT{slotNull_cmd_val}:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, cell=repcap.Cell.Default, slotNull=repcap.SlotNull.Default) -> enums.TdscdmaSlotModeUp:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:UP:CELL<ST>:SLOT<CH0>:MODE \n
		Snippet: value: enums.TdscdmaSlotModeUp = driver.source.bb.tdscdma.up.cell.slot.mode.get(cell = repcap.Cell.Default, slotNull = repcap.SlotNull.Default) \n
		Sets the mode in which the slot is to work. \n
			:param cell: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cell')
			:param slotNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
			:return: mode: DEDicated| PRACh DEDicated The instrument generates a signal with a dedicated physical control channel (DPCCH) and up to six dedicated physical data channels (DPDCH) . The signal is used for voice and data transmission. PRACh The instrument generates a single physical random access channel (PRACH) . This channel is needed to set up the connection between the mobile station and the base station."""
		cell_cmd_val = self._cmd_group.get_repcap_cmd_value(cell, repcap.Cell)
		slotNull_cmd_val = self._cmd_group.get_repcap_cmd_value(slotNull, repcap.SlotNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:TDSCdma:UP:CELL{cell_cmd_val}:SLOT{slotNull_cmd_val}:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.TdscdmaSlotModeUp)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CountCls:
	"""Count commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("count", core, parent)

	def get(self, vehicle=repcap.Vehicle.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RECeiver:[V<ST>]:ENVironment:FULL:AREA:COUNt \n
		Snippet: value: int = driver.source.bb.gnss.receiver.v.environment.full.area.count.get(vehicle = repcap.Vehicle.Default) \n
		Sets the number of the obscured area/zones. \n
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')
			:return: areas_count: integer Range: 0 to 50"""
		vehicle_cmd_val = self._cmd_group.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:RECeiver:V{vehicle_cmd_val}:ENVironment:FULL:AREA:COUNt?')
		return Conversions.str_to_int(response)



from ............Internal.Core import Core
from ............Internal.CommandsGroup import CommandsGroup
from ............Internal import Conversions
from ............ import enums
from ............ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SchSizeCls:
	"""SchSize commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("schSize", core, parent)

	def set(self, sub_chan_size: enums.ResPoolScSizeAll, userNull=repcap.UserNull.Default, cellNull=repcap.CellNull.Default, bwPartNull=repcap.BwPartNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<US(CH0)>:CELL<CC(ST0)>:SL:BWP<BWP(DIR0)>:RESPool:RES:SCHSize \n
		Snippet: driver.source.bb.nr5G.ubwp.user.cell.sl.bwp.resPool.res.schSize.set(sub_chan_size = enums.ResPoolScSizeAll.R10, userNull = repcap.UserNull.Default, cellNull = repcap.CellNull.Default, bwPartNull = repcap.BwPartNull.Default) \n
		Selects the size of a resource pool in terms of resource blocks. \n
			:param sub_chan_size: R10| R12| R15| R20| R25| R50| R75 The available sizes depend on the number of PRBs the resource pool uses ([:SOURcehw]:BB:NR5G:UBWP:USERus:CELLcc:SL:BWPbwp:RESPool:RESgr0:NPRB) .
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Bwp')
		"""
		param = Conversions.enum_scalar_to_str(sub_chan_size, enums.ResPoolScSizeAll)
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:CELL{cellNull_cmd_val}:SL:BWP{bwPartNull_cmd_val}:RESPool:RES:SCHSize {param}')

	# noinspection PyTypeChecker
	def get(self, userNull=repcap.UserNull.Default, cellNull=repcap.CellNull.Default, bwPartNull=repcap.BwPartNull.Default) -> enums.ResPoolScSizeAll:
		"""SCPI: [SOURce<HW>]:BB:NR5G:UBWP:USER<US(CH0)>:CELL<CC(ST0)>:SL:BWP<BWP(DIR0)>:RESPool:RES:SCHSize \n
		Snippet: value: enums.ResPoolScSizeAll = driver.source.bb.nr5G.ubwp.user.cell.sl.bwp.resPool.res.schSize.get(userNull = repcap.UserNull.Default, cellNull = repcap.CellNull.Default, bwPartNull = repcap.BwPartNull.Default) \n
		Selects the size of a resource pool in terms of resource blocks. \n
			:param userNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'User')
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param bwPartNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Bwp')
			:return: sub_chan_size: No help available"""
		userNull_cmd_val = self._cmd_group.get_repcap_cmd_value(userNull, repcap.UserNull)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		bwPartNull_cmd_val = self._cmd_group.get_repcap_cmd_value(bwPartNull, repcap.BwPartNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:UBWP:USER{userNull_cmd_val}:CELL{cellNull_cmd_val}:SL:BWP{bwPartNull_cmd_val}:RESPool:RES:SCHSize?')
		return Conversions.str_to_scalar_enum(response, enums.ResPoolScSizeAll)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ToaDataCls:
	"""ToaData commands group definition. 7 total commands, 2 Subgroups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("toaData", core, parent)

	@property
	def date(self):
		"""date commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_date'):
			from .Date import DateCls
			self._date = DateCls(self._core, self._cmd_group)
		return self._date

	@property
	def time(self):
		"""time commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_time'):
			from .Time import TimeCls
			self._time = TimeCls(self._core, self._cmd_group)
		return self._time

	def get_duration(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ADGeneration:GPS:TOAData:DURation \n
		Snippet: value: float = driver.source.bb.gnss.adGeneration.gps.toaData.get_duration() \n
		Sets the duration of the assistance data. \n
			:return: duration: float Range: 1E-3 to 5E3
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:ADGeneration:GPS:TOAData:DURation?')
		return Conversions.str_to_float(response)

	def set_duration(self, duration: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ADGeneration:GPS:TOAData:DURation \n
		Snippet: driver.source.bb.gnss.adGeneration.gps.toaData.set_duration(duration = 1.0) \n
		Sets the duration of the assistance data. \n
			:param duration: float Range: 1E-3 to 5E3
		"""
		param = Conversions.decimal_value_to_str(duration)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:ADGeneration:GPS:TOAData:DURation {param}')

	def get_resolution(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ADGeneration:GPS:TOAData:RESolution \n
		Snippet: value: float = driver.source.bb.gnss.adGeneration.gps.toaData.get_resolution() \n
		Sets the resolution of the assistance data. \n
			:return: resolution: float Range: 1E-3 to 5
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:ADGeneration:GPS:TOAData:RESolution?')
		return Conversions.str_to_float(response)

	def set_resolution(self, resolution: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ADGeneration:GPS:TOAData:RESolution \n
		Snippet: driver.source.bb.gnss.adGeneration.gps.toaData.set_resolution(resolution = 1.0) \n
		Sets the resolution of the assistance data. \n
			:param resolution: float Range: 1E-3 to 5
		"""
		param = Conversions.decimal_value_to_str(resolution)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:ADGeneration:GPS:TOAData:RESolution {param}')

	# noinspection PyTypeChecker
	def get_tbasis(self) -> enums.TimeBasis:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ADGeneration:GPS:TOAData:TBASis \n
		Snippet: value: enums.TimeBasis = driver.source.bb.gnss.adGeneration.gps.toaData.get_tbasis() \n
		Determines the timebase used to enter the time of assistance data parameters. \n
			:return: time_basis: UTC| GPS| GST| GLO| BDT| NAV
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:ADGeneration:GPS:TOAData:TBASis?')
		return Conversions.str_to_scalar_enum(response, enums.TimeBasis)

	def set_tbasis(self, time_basis: enums.TimeBasis) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ADGeneration:GPS:TOAData:TBASis \n
		Snippet: driver.source.bb.gnss.adGeneration.gps.toaData.set_tbasis(time_basis = enums.TimeBasis.BDT) \n
		Determines the timebase used to enter the time of assistance data parameters. \n
			:param time_basis: UTC| GPS| GST| GLO| BDT| NAV
		"""
		param = Conversions.enum_scalar_to_str(time_basis, enums.TimeBasis)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:ADGeneration:GPS:TOAData:TBASis {param}')

	def get_to_week(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ADGeneration:GPS:TOAData:TOWeek \n
		Snippet: value: int = driver.source.bb.gnss.adGeneration.gps.toaData.get_to_week() \n
		Enabled for GPS timebase ([:SOURce<hw>]:BB:GNSS:ADGeneration:GPS:TOAData:TBASis) . Determines the Time of Week (TOW) the
		assistance data is generated for. \n
			:return: tow: integer Range: -604800 to 604800
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:ADGeneration:GPS:TOAData:TOWeek?')
		return Conversions.str_to_int(response)

	def set_to_week(self, tow: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ADGeneration:GPS:TOAData:TOWeek \n
		Snippet: driver.source.bb.gnss.adGeneration.gps.toaData.set_to_week(tow = 1) \n
		Enabled for GPS timebase ([:SOURce<hw>]:BB:GNSS:ADGeneration:GPS:TOAData:TBASis) . Determines the Time of Week (TOW) the
		assistance data is generated for. \n
			:param tow: integer Range: -604800 to 604800
		"""
		param = Conversions.decimal_value_to_str(tow)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:ADGeneration:GPS:TOAData:TOWeek {param}')

	def get_wnumber(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ADGeneration:GPS:TOAData:WNUMber \n
		Snippet: value: int = driver.source.bb.gnss.adGeneration.gps.toaData.get_wnumber() \n
		Enabled for GPS timebase ([:SOURce<hw>]:BB:GNSS:ADGeneration:QZSS:TOAData:TBASis) . Sets the week number (WN) the
		assistance data is generated for. \n
			:return: week_number: integer Range: 0 to 9999.0*53
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:ADGeneration:GPS:TOAData:WNUMber?')
		return Conversions.str_to_int(response)

	def set_wnumber(self, week_number: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ADGeneration:GPS:TOAData:WNUMber \n
		Snippet: driver.source.bb.gnss.adGeneration.gps.toaData.set_wnumber(week_number = 1) \n
		Enabled for GPS timebase ([:SOURce<hw>]:BB:GNSS:ADGeneration:QZSS:TOAData:TBASis) . Sets the week number (WN) the
		assistance data is generated for. \n
			:param week_number: integer Range: 0 to 9999.0*53
		"""
		param = Conversions.decimal_value_to_str(week_number)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:ADGeneration:GPS:TOAData:WNUMber {param}')

	def clone(self) -> 'ToaDataCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ToaDataCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CbwCls:
	"""Cbw commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cbw", core, parent)

	def set(self, chan_bandwidth: enums.Nr5Gcbw, cellNull=repcap.CellNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CELL<CC(CH0)>:CBW \n
		Snippet: driver.source.bb.nr5G.node.cell.cbw.set(chan_bandwidth = enums.Nr5Gcbw.BW10, cellNull = repcap.CellNull.Default) \n
		Selects the bandwidth of the node carrier. Some bandwidths are available with R&S SMBVB-K171. \n
			:param chan_bandwidth: BW5 | BW10 | BW15 | BW20 | BW25 | BW30 | BW35 | BW40 | BW45 | BW50 | BW60 | BW70 | BW80 | BW90 | BW100 | BW200 | BW400 | BW800 | BW1600 | BW2000
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
		"""
		param = Conversions.enum_scalar_to_str(chan_bandwidth, enums.Nr5Gcbw)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:NODE:CELL{cellNull_cmd_val}:CBW {param}')

	# noinspection PyTypeChecker
	def get(self, cellNull=repcap.CellNull.Default) -> enums.Nr5Gcbw:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CELL<CC(CH0)>:CBW \n
		Snippet: value: enums.Nr5Gcbw = driver.source.bb.nr5G.node.cell.cbw.get(cellNull = repcap.CellNull.Default) \n
		Selects the bandwidth of the node carrier. Some bandwidths are available with R&S SMBVB-K171. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:return: chan_bandwidth: BW5 | BW10 | BW15 | BW20 | BW25 | BW30 | BW35 | BW40 | BW45 | BW50 | BW60 | BW70 | BW80 | BW90 | BW100 | BW200 | BW400 | BW800 | BW1600 | BW2000"""
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:NODE:CELL{cellNull_cmd_val}:CBW?')
		return Conversions.str_to_scalar_enum(response, enums.Nr5Gcbw)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from .........Internal.Utilities import trim_str_response
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ZpiCls:
	"""Zpi commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("zpi", core, parent)

	def set(self, zero_pow_conf: str, cellNull=repcap.CellNull.Default, indexNull=repcap.IndexNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:CSIS:[CELL<CH0>]:[ZPRS<ST0>]:ZPI \n
		Snippet: driver.source.bb.eutra.downlink.csis.cell.zprs.zpi.set(zero_pow_conf = rawAbc, cellNull = repcap.CellNull.Default, indexNull = repcap.IndexNull.Default) \n
		Sets the parameter ICSI-RS for CSI-RS with zero transmission power. \n
			:param zero_pow_conf: integer Range: 0 to 154
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param indexNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Zprs')
		"""
		param = Conversions.value_to_str(zero_pow_conf)
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		indexNull_cmd_val = self._cmd_group.get_repcap_cmd_value(indexNull, repcap.IndexNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:CSIS:CELL{cellNull_cmd_val}:ZPRS{indexNull_cmd_val}:ZPI {param}')

	def get(self, cellNull=repcap.CellNull.Default, indexNull=repcap.IndexNull.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:CSIS:[CELL<CH0>]:[ZPRS<ST0>]:ZPI \n
		Snippet: value: str = driver.source.bb.eutra.downlink.csis.cell.zprs.zpi.get(cellNull = repcap.CellNull.Default, indexNull = repcap.IndexNull.Default) \n
		Sets the parameter ICSI-RS for CSI-RS with zero transmission power. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:param indexNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Zprs')
			:return: zero_pow_conf: integer Range: 0 to 154"""
		cellNull_cmd_val = self._cmd_group.get_repcap_cmd_value(cellNull, repcap.CellNull)
		indexNull_cmd_val = self._cmd_group.get_repcap_cmd_value(indexNull, repcap.IndexNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:CSIS:CELL{cellNull_cmd_val}:ZPRS{indexNull_cmd_val}:ZPI?')
		return trim_str_response(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: bool, stream=repcap.Stream.Default, iqConnector=repcap.IqConnector.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:STReam<ST>:OUTPut:BBMM<CH>:STATe \n
		Snippet: driver.source.bb.gnss.stream.output.bbmm.state.set(state = False, stream = repcap.Stream.Default, iqConnector = repcap.IqConnector.Default) \n
		No command help available \n
			:param state: No help available
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Stream')
			:param iqConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bbmm')
		"""
		param = Conversions.bool_to_str(state)
		stream_cmd_val = self._cmd_group.get_repcap_cmd_value(stream, repcap.Stream)
		iqConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(iqConnector, repcap.IqConnector)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:STReam{stream_cmd_val}:OUTPut:BBMM{iqConnector_cmd_val}:STATe {param}')

	def get(self, stream=repcap.Stream.Default, iqConnector=repcap.IqConnector.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:STReam<ST>:OUTPut:BBMM<CH>:STATe \n
		Snippet: value: bool = driver.source.bb.gnss.stream.output.bbmm.state.get(stream = repcap.Stream.Default, iqConnector = repcap.IqConnector.Default) \n
		No command help available \n
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Stream')
			:param iqConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bbmm')
			:return: state: No help available"""
		stream_cmd_val = self._cmd_group.get_repcap_cmd_value(stream, repcap.Stream)
		iqConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(iqConnector, repcap.IqConnector)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:STReam{stream_cmd_val}:OUTPut:BBMM{iqConnector_cmd_val}:STATe?')
		return Conversions.str_to_bool(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StageCls:
	"""Stage commands group definition. 4 total commands, 0 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("stage", core, parent)

	def get_frequency(self) -> int:
		"""SCPI: CALibration:LEVel:AMPLifier:STAGe:FREQuenz \n
		Snippet: value: int = driver.calibration.level.amplifier.stage.get_frequency() \n
		No command help available \n
			:return: freq_stage: No help available
		"""
		response = self._core.io.query_str('CALibration:LEVel:AMPLifier:STAGe:FREQuenz?')
		return Conversions.str_to_int(response)

	def set_frequency(self, freq_stage: int) -> None:
		"""SCPI: CALibration:LEVel:AMPLifier:STAGe:FREQuenz \n
		Snippet: driver.calibration.level.amplifier.stage.set_frequency(freq_stage = 1) \n
		No command help available \n
			:param freq_stage: No help available
		"""
		param = Conversions.decimal_value_to_str(freq_stage)
		self._core.io.write(f'CALibration:LEVel:AMPLifier:STAGe:FREQuenz {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.CalPowAmpStagMode:
		"""SCPI: CALibration:LEVel:AMPLifier:STAGe:MODE \n
		Snippet: value: enums.CalPowAmpStagMode = driver.calibration.level.amplifier.stage.get_mode() \n
		No command help available \n
			:return: mode: No help available
		"""
		response = self._core.io.query_str('CALibration:LEVel:AMPLifier:STAGe:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.CalPowAmpStagMode)

	def set_mode(self, mode: enums.CalPowAmpStagMode) -> None:
		"""SCPI: CALibration:LEVel:AMPLifier:STAGe:MODE \n
		Snippet: driver.calibration.level.amplifier.stage.set_mode(mode = enums.CalPowAmpStagMode.AUTO) \n
		No command help available \n
			:param mode: No help available
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.CalPowAmpStagMode)
		self._core.io.write(f'CALibration:LEVel:AMPLifier:STAGe:MODE {param}')

	def get_sub(self) -> int:
		"""SCPI: CALibration:LEVel:AMPLifier:STAGe:SUB \n
		Snippet: value: int = driver.calibration.level.amplifier.stage.get_sub() \n
		No command help available \n
			:return: sub_stage: No help available
		"""
		response = self._core.io.query_str('CALibration:LEVel:AMPLifier:STAGe:SUB?')
		return Conversions.str_to_int(response)

	def set_sub(self, sub_stage: int) -> None:
		"""SCPI: CALibration:LEVel:AMPLifier:STAGe:SUB \n
		Snippet: driver.calibration.level.amplifier.stage.set_sub(sub_stage = 1) \n
		No command help available \n
			:param sub_stage: No help available
		"""
		param = Conversions.decimal_value_to_str(sub_stage)
		self._core.io.write(f'CALibration:LEVel:AMPLifier:STAGe:SUB {param}')

	def get_value(self) -> int:
		"""SCPI: CALibration:LEVel:AMPLifier:STAGe \n
		Snippet: value: int = driver.calibration.level.amplifier.stage.get_value() \n
		No command help available \n
			:return: stage: No help available
		"""
		response = self._core.io.query_str('CALibration:LEVel:AMPLifier:STAGe?')
		return Conversions.str_to_int(response)

	def set_value(self, stage: int) -> None:
		"""SCPI: CALibration:LEVel:AMPLifier:STAGe \n
		Snippet: driver.calibration.level.amplifier.stage.set_value(stage = 1) \n
		No command help available \n
			:param stage: No help available
		"""
		param = Conversions.decimal_value_to_str(stage)
		self._core.io.write(f'CALibration:LEVel:AMPLifier:STAGe {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CrsSeqCls:
	"""CrsSeq commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("crsSeq", core, parent)

	def set(self, crs_seq_info: enums.NumbersE, carrier=repcap.Carrier.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:CARRier<CH>:NIOT:CRSSeq \n
		Snippet: driver.source.bb.eutra.downlink.carrier.niot.crsSeq.set(crs_seq_info = enums.NumbersE._0, carrier = repcap.Carrier.Default) \n
		Sets the CRS sequence info. \n
			:param crs_seq_info: 0| 1| 2| 3| 4| 5| 6| 7| 8| 9| 10| 11| 12| 13| 14| 15| 16| 17| 18| 19| 20| 21| 22| 23| 24| 25| 26| 27| 28| 29| 30| 31
			:param carrier: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Carrier')
		"""
		param = Conversions.enum_scalar_to_str(crs_seq_info, enums.NumbersE)
		carrier_cmd_val = self._cmd_group.get_repcap_cmd_value(carrier, repcap.Carrier)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:CARRier{carrier_cmd_val}:NIOT:CRSSeq {param}')

	# noinspection PyTypeChecker
	def get(self, carrier=repcap.Carrier.Default) -> enums.NumbersE:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:CARRier<CH>:NIOT:CRSSeq \n
		Snippet: value: enums.NumbersE = driver.source.bb.eutra.downlink.carrier.niot.crsSeq.get(carrier = repcap.Carrier.Default) \n
		Sets the CRS sequence info. \n
			:param carrier: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Carrier')
			:return: crs_seq_info: 0| 1| 2| 3| 4| 5| 6| 7| 8| 9| 10| 11| 12| 13| 14| 15| 16| 17| 18| 19| 20| 21| 22| 23| 24| 25| 26| 27| 28| 29| 30| 31"""
		carrier_cmd_val = self._cmd_group.get_repcap_cmd_value(carrier, repcap.Carrier)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:CARRier{carrier_cmd_val}:NIOT:CRSSeq?')
		return Conversions.str_to_scalar_enum(response, enums.NumbersE)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import enums
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TalignmentCls:
	"""Talignment commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("talignment", core, parent)

	def set(self, tb_alignment: enums.TbAlign, satelliteSvid=repcap.SatelliteSvid.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SVID<CH>:GLONass:NMESsage:NAV:EPHemeris:TALignment \n
		Snippet: driver.source.bb.gnss.svid.glonass.nmessage.nav.ephemeris.talignment.set(tb_alignment = enums.TbAlign.EVEN, satelliteSvid = repcap.SatelliteSvid.Default) \n
		Sets the tb alignment - P2. \n
			:param tb_alignment: EVEN| ODD
			:param satelliteSvid: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Svid')
		"""
		param = Conversions.enum_scalar_to_str(tb_alignment, enums.TbAlign)
		satelliteSvid_cmd_val = self._cmd_group.get_repcap_cmd_value(satelliteSvid, repcap.SatelliteSvid)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SVID{satelliteSvid_cmd_val}:GLONass:NMESsage:NAV:EPHemeris:TALignment {param}')

	# noinspection PyTypeChecker
	def get(self, satelliteSvid=repcap.SatelliteSvid.Default) -> enums.TbAlign:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SVID<CH>:GLONass:NMESsage:NAV:EPHemeris:TALignment \n
		Snippet: value: enums.TbAlign = driver.source.bb.gnss.svid.glonass.nmessage.nav.ephemeris.talignment.get(satelliteSvid = repcap.SatelliteSvid.Default) \n
		Sets the tb alignment - P2. \n
			:param satelliteSvid: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Svid')
			:return: tb_alignment: EVEN| ODD"""
		satelliteSvid_cmd_val = self._cmd_group.get_repcap_cmd_value(satelliteSvid, repcap.SatelliteSvid)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:SVID{satelliteSvid_cmd_val}:GLONass:NMESsage:NAV:EPHemeris:TALignment?')
		return Conversions.str_to_scalar_enum(response, enums.TbAlign)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HtControlCls:
	"""HtControl commands group definition. 13 total commands, 11 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("htControl", core, parent)

	@property
	def acConstraint(self):
		"""acConstraint commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_acConstraint'):
			from .AcConstraint import AcConstraintCls
			self._acConstraint = AcConstraintCls(self._core, self._cmd_group)
		return self._acConstraint

	@property
	def calibration(self):
		"""calibration commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_calibration'):
			from .Calibration import CalibrationCls
			self._calibration = CalibrationCls(self._core, self._cmd_group)
		return self._calibration

	@property
	def csiSteering(self):
		"""csiSteering commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_csiSteering'):
			from .CsiSteering import CsiSteeringCls
			self._csiSteering = CsiSteeringCls(self._core, self._cmd_group)
		return self._csiSteering

	@property
	def frequest(self):
		"""frequest commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_frequest'):
			from .Frequest import FrequestCls
			self._frequest = FrequestCls(self._core, self._cmd_group)
		return self._frequest

	@property
	def hvIndicator(self):
		"""hvIndicator commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_hvIndicator'):
			from .HvIndicator import HvIndicatorCls
			self._hvIndicator = HvIndicatorCls(self._core, self._cmd_group)
		return self._hvIndicator

	@property
	def laControl(self):
		"""laControl commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_laControl'):
			from .LaControl import LaControlCls
			self._laControl = LaControlCls(self._core, self._cmd_group)
		return self._laControl

	@property
	def ndp(self):
		"""ndp commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ndp'):
			from .Ndp import NdpCls
			self._ndp = NdpCls(self._core, self._cmd_group)
		return self._ndp

	@property
	def rdgMore(self):
		"""rdgMore commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rdgMore'):
			from .RdgMore import RdgMoreCls
			self._rdgMore = RdgMoreCls(self._core, self._cmd_group)
		return self._rdgMore

	@property
	def reserved(self):
		"""reserved commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_reserved'):
			from .Reserved import ReservedCls
			self._reserved = ReservedCls(self._core, self._cmd_group)
		return self._reserved

	@property
	def sreserved(self):
		"""sreserved commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sreserved'):
			from .Sreserved import SreservedCls
			self._sreserved = SreservedCls(self._core, self._cmd_group)
		return self._sreserved

	@property
	def zlf(self):
		"""zlf commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_zlf'):
			from .Zlf import ZlfCls
			self._zlf = ZlfCls(self._core, self._cmd_group)
		return self._zlf

	def set(self, ht_control: str, frameBlock=repcap.FrameBlock.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:MAC:HTControl \n
		Snippet: driver.source.bb.wlnn.fblock.mac.htControl.set(ht_control = rawAbc, frameBlock = repcap.FrameBlock.Default) \n
		Sets the value for the HT control field. \n
			:param ht_control: integer Range: #H00000000,32 to #HFFFFFFFF,32
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
		"""
		param = Conversions.value_to_str(ht_control)
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:MAC:HTControl {param}')

	def get(self, frameBlock=repcap.FrameBlock.Default) -> str:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:MAC:HTControl \n
		Snippet: value: str = driver.source.bb.wlnn.fblock.mac.htControl.get(frameBlock = repcap.FrameBlock.Default) \n
		Sets the value for the HT control field. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:return: ht_control: integer Range: #H00000000,32 to #HFFFFFFFF,32"""
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:MAC:HTControl?')
		return trim_str_response(response)

	def clone(self) -> 'HtControlCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = HtControlCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.StructBase import StructBase
from .......Internal.ArgStruct import ArgStruct


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class GlonassCls:
	"""Glonass commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("glonass", core, parent)

	# noinspection PyTypeChecker
	class DateStruct(StructBase):  # From ReadStructDefinition CmdPropertyTemplate.xml
		"""Structure for reading output parameters. Fields: \n
			- Year: int: integer Range: 1980 to 9999
			- Month: int: integer Range: 1 to 12
			- Day: int: integer Range: 1 to 31"""
		__meta_args_list = [
			ArgStruct.scalar_int('Year'),
			ArgStruct.scalar_int('Month'),
			ArgStruct.scalar_int('Day')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Year: int = None
			self.Month: int = None
			self.Day: int = None

	def get_date(self) -> DateStruct:
		"""SCPI: [SOURce<HW>]:BB:GNSS:TIME:STARt:GLONass:DATE \n
		Snippet: value: DateStruct = driver.source.bb.gnss.time.start.glonass.get_date() \n
		Queries the date at the simulation start time of the selected navigation standard. \n
			:return: structure: for return value, see the help for DateStruct structure arguments.
		"""
		return self._core.io.query_struct('SOURce<HwInstance>:BB:GNSS:TIME:STARt:GLONass:DATE?', self.__class__.DateStruct())

	def get_offset(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:GNSS:TIME:STARt:GLONass:OFFSet \n
		Snippet: value: float = driver.source.bb.gnss.time.start.glonass.get_offset() \n
		Queries the time offset between the time in the navigation standard and UTC. \n
			:return: utc_offset: float Range: -1E6 to 1E6
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:TIME:STARt:GLONass:OFFSet?')
		return Conversions.str_to_float(response)

	# noinspection PyTypeChecker
	class TimeStruct(StructBase):  # From ReadStructDefinition CmdPropertyTemplate.xml
		"""Structure for reading output parameters. Fields: \n
			- Hour: int: integer Range: 0 to 23
			- Minute: int: integer Range: 0 to 59
			- Second: float: float Range: 0 to 59.999"""
		__meta_args_list = [
			ArgStruct.scalar_int('Hour'),
			ArgStruct.scalar_int('Minute'),
			ArgStruct.scalar_float('Second')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Hour: int = None
			self.Minute: int = None
			self.Second: float = None

	def get_time(self) -> TimeStruct:
		"""SCPI: [SOURce<HW>]:BB:GNSS:TIME:STARt:GLONass:TIME \n
		Snippet: value: TimeStruct = driver.source.bb.gnss.time.start.glonass.get_time() \n
		Queries the simulation start time of the selected navigation standard. \n
			:return: structure: for return value, see the help for TimeStruct structure arguments.
		"""
		return self._core.io.query_struct('SOURce<HwInstance>:BB:GNSS:TIME:STARt:GLONass:TIME?', self.__class__.TimeStruct())



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Types import DataType
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IconnectCls:
	"""Iconnect commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("iconnect", core, parent)

	def set(self, ipart_instr_name: str, rf_path: str, iqConnector=repcap.IqConnector.Default) -> None:
		"""SCPI: SCONfiguration:EXTernal:IQOutput<CH>:REMote:ICONnect \n
		Snippet: driver.sconfiguration.external.iqOutput.remote.iconnect.set(ipart_instr_name = 'abc', rf_path = 'abc', iqConnector = repcap.IqConnector.Default) \n
		Selects an external instrument for the selected connector and triggers connection. \n
			:param ipart_instr_name: string Instrument alias name, as retrieved with the command method RsSmbv.Sconfiguration.External.Remote.listPy or defined with the command method RsSmbv.Sconfiguration.External.Remote.Add.set.
			:param rf_path: string Determines the used RF output of the external instrument. For a one-path instrument, the output path is fixed.
			:param iqConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'IqOutput')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('ipart_instr_name', ipart_instr_name, DataType.String), ArgSingle('rf_path', rf_path, DataType.String))
		iqConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(iqConnector, repcap.IqConnector)
		self._core.io.write(f'SCONfiguration:EXTernal:IQOutput{iqConnector_cmd_val}:REMote:ICONnect {param}'.rstrip())



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def get(self, channel=repcap.Channel.Default) -> float:
		"""SCPI: SENSe<CH>:[POWer]:FILTer:LENGth:AUTO \n
		Snippet: value: float = driver.sense.power.filterPy.length.auto.get(channel = repcap.Channel.Default) \n
		Queries the current filter length in filter mode AUTO (method RsSmbv.Sense.Power.FilterPy.TypePy.set) \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Sense')
			:return: auto: float Range: 1 to 65536"""
		channel_cmd_val = self._cmd_group.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SENSe{channel_cmd_val}:POWer:FILTer:LENGth:AUTO?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PccpchCls:
	"""Pccpch commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pccpch", core, parent)

	def get_state(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:DOWN:PPARameter:PCCPch:STATe \n
		Snippet: value: bool = driver.source.bb.tdscdma.down.pparameter.pccpch.get_state() \n
		Defines, if P-CCPCH is used in the scenario or not. If P-CCPCH is used, both P-CCPCHs are activated in slot 0 with
		spreading code 0+1. \n
			:return: state: 1| ON| 0| OFF
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:TDSCdma:DOWN:PPARameter:PCCPch:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:TDSCdma:DOWN:PPARameter:PCCPch:STATe \n
		Snippet: driver.source.bb.tdscdma.down.pparameter.pccpch.set_state(state = False) \n
		Defines, if P-CCPCH is used in the scenario or not. If P-CCPCH is used, both P-CCPCHs are activated in slot 0 with
		spreading code 0+1. \n
			:param state: 1| ON| 0| OFF
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:BB:TDSCdma:DOWN:PPARameter:PCCPch:STATe {param}')



from ..............Internal.Core import Core
from ..............Internal.CommandsGroup import CommandsGroup
from ..............Internal.RepeatedCapability import RepeatedCapability
from .............. import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResCls:
	"""Res commands group definition. 24 total commands, 18 Subgroups, 0 group commands
	Repeated Capability: ResourceNull, default value after init: ResourceNull.Nr0"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("res", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_resourceNull_get', 'repcap_resourceNull_set', repcap.ResourceNull.Nr0)

	def repcap_resourceNull_set(self, resourceNull: repcap.ResourceNull) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to ResourceNull.Default
		Default value after init: ResourceNull.Nr0"""
		self._cmd_group.set_repcap_enum_value(resourceNull)

	def repcap_resourceNull_get(self) -> repcap.ResourceNull:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def apMap(self):
		"""apMap commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_apMap'):
			from .ApMap import ApMapCls
			self._apMap = ApMapCls(self._core, self._cmd_group)
		return self._apMap

	@property
	def bhop(self):
		"""bhop commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bhop'):
			from .Bhop import BhopCls
			self._bhop = BhopCls(self._core, self._cmd_group)
		return self._bhop

	@property
	def bsrs(self):
		"""bsrs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bsrs'):
			from .Bsrs import BsrsCls
			self._bsrs = BsrsCls(self._core, self._cmd_group)
		return self._bsrs

	@property
	def coffset(self):
		"""coffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_coffset'):
			from .Coffset import CoffsetCls
			self._coffset = CoffsetCls(self._core, self._cmd_group)
		return self._coffset

	@property
	def csrs(self):
		"""csrs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_csrs'):
			from .Csrs import CsrsCls
			self._csrs = CsrsCls(self._core, self._cmd_group)
		return self._csrs

	@property
	def fpos(self):
		"""fpos commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fpos'):
			from .Fpos import FposCls
			self._fpos = FposCls(self._core, self._cmd_group)
		return self._fpos

	@property
	def fqShift(self):
		"""fqShift commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_fqShift'):
			from .FqShift import FqShiftCls
			self._fqShift = FqShiftCls(self._core, self._cmd_group)
		return self._fqShift

	@property
	def fs(self):
		"""fs commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_fs'):
			from .Fs import FsCls
			self._fs = FsCls(self._core, self._cmd_group)
		return self._fs

	@property
	def naPort(self):
		"""naPort commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_naPort'):
			from .NaPort import NaPortCls
			self._naPort = NaPortCls(self._core, self._cmd_group)
		return self._naPort

	@property
	def offset(self):
		"""offset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_offset'):
			from .Offset import OffsetCls
			self._offset = OffsetCls(self._core, self._cmd_group)
		return self._offset

	@property
	def per(self):
		"""per commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_per'):
			from .Per import PerCls
			self._per = PerCls(self._core, self._cmd_group)
		return self._per

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def ptrs(self):
		"""ptrs commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ptrs'):
			from .Ptrs import PtrsCls
			self._ptrs = PtrsCls(self._core, self._cmd_group)
		return self._ptrs

	@property
	def refactor(self):
		"""refactor commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_refactor'):
			from .Refactor import RefactorCls
			self._refactor = RefactorCls(self._core, self._cmd_group)
		return self._refactor

	@property
	def seq(self):
		"""seq commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_seq'):
			from .Seq import SeqCls
			self._seq = SeqCls(self._core, self._cmd_group)
		return self._seq

	@property
	def spos(self):
		"""spos commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_spos'):
			from .Spos import SposCls
			self._spos = SposCls(self._core, self._cmd_group)
		return self._spos

	@property
	def symNumber(self):
		"""symNumber commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_symNumber'):
			from .SymNumber import SymNumberCls
			self._symNumber = SymNumberCls(self._core, self._cmd_group)
		return self._symNumber

	@property
	def trtComb(self):
		"""trtComb commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_trtComb'):
			from .TrtComb import TrtCombCls
			self._trtComb = TrtCombCls(self._core, self._cmd_group)
		return self._trtComb

	def clone(self) -> 'ResCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ResCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class WaveformCls:
	"""Waveform commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("waveform", core, parent)

	def set_create(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:GBAS:WAVeform:CREate \n
		Snippet: driver.source.bb.gbas.waveform.set_create(filename = 'abc') \n
		With enabled signal generation, triggers the instrument to save the current settings of an arbitrary waveform signal in a
		waveform file with predefined extension *.wv. You can define the filename and the directory, in that you want to save the
		file. Using the ARB modulation source, you can play back waveform files and/or process the file to generate multi-carrier
		or multi-segment signals. \n
			:param filename: string
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:GBAS:WAVeform:CREate {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums
from .... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SourceCls:
	"""Source commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("source", core, parent)

	def set(self, source: enums.LfSource, lfOutput=repcap.LfOutput.Default) -> None:
		"""SCPI: [SOURce]:LFOutput<CH>:SOURce \n
		Snippet: driver.source.lfOutput.source.set(source = enums.LfSource.AM, lfOutput = repcap.LfOutput.Default) \n
		Determines the LF signal to be synchronized, when monitoring is enabled. \n
			:param source: LF1| LF2| NOISe| AM| FMPM| EXT1 LF1|LF2 Selects an internally generated LF signal. NOISe Selects an internally generated noise signal. EXT1 Selects an externally supplied LF signal AM Selects the AM signal. FMPM Selects the signal also used by the frequency or phase modulations.
			:param lfOutput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'LfOutput')
		"""
		param = Conversions.enum_scalar_to_str(source, enums.LfSource)
		lfOutput_cmd_val = self._cmd_group.get_repcap_cmd_value(lfOutput, repcap.LfOutput)
		self._core.io.write(f'SOURce:LFOutput{lfOutput_cmd_val}:SOURce {param}')

	# noinspection PyTypeChecker
	def get(self, lfOutput=repcap.LfOutput.Default) -> enums.LfSource:
		"""SCPI: [SOURce]:LFOutput<CH>:SOURce \n
		Snippet: value: enums.LfSource = driver.source.lfOutput.source.get(lfOutput = repcap.LfOutput.Default) \n
		Determines the LF signal to be synchronized, when monitoring is enabled. \n
			:param lfOutput: optional repeated capability selector. Default value: Nr1 (settable in the interface 'LfOutput')
			:return: source: LF1| LF2| NOISe| AM| FMPM| EXT1 LF1|LF2 Selects an internally generated LF signal. NOISe Selects an internally generated noise signal. EXT1 Selects an externally supplied LF signal AM Selects the AM signal. FMPM Selects the signal also used by the frequency or phase modulations."""
		lfOutput_cmd_val = self._cmd_group.get_repcap_cmd_value(lfOutput, repcap.LfOutput)
		response = self._core.io.query_str(f'SOURce:LFOutput{lfOutput_cmd_val}:SOURce?')
		return Conversions.str_to_scalar_enum(response, enums.LfSource)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ItimeCls:
	"""Itime commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("itime", core, parent)

	def set(self, itime: float, frameBlock=repcap.FrameBlock.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:ITIMe \n
		Snippet: driver.source.bb.wlnn.fblock.itime.set(itime = 1.0, frameBlock = repcap.FrameBlock.Default) \n
		Sets the time interval separating two frames in this frame block. The default unit for the time interval are seconds.
		However, the time interval can be set in milliseconds. In this case the unit has to be set. \n
			:param itime: float Range: 0 to 1
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
		"""
		param = Conversions.decimal_value_to_str(itime)
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:ITIMe {param}')

	def get(self, frameBlock=repcap.FrameBlock.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:ITIMe \n
		Snippet: value: float = driver.source.bb.wlnn.fblock.itime.get(frameBlock = repcap.FrameBlock.Default) \n
		Sets the time interval separating two frames in this frame block. The default unit for the time interval are seconds.
		However, the time interval can be set in milliseconds. In this case the unit has to be set. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:return: itime: float Range: 0 to 1"""
		frameBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:ITIMe?')
		return Conversions.str_to_float(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FormatPyCls:
	"""FormatPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("formatPy", core, parent)

	def set(self, format_py: enums.EutraPdccFmt2, subframeNull=repcap.SubframeNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:[SUBF<ST0>]:ENCC:PDCCh:FORMat \n
		Snippet: driver.source.bb.eutra.downlink.subf.encc.pdcch.formatPy.set(format_py = enums.EutraPdccFmt2._0, subframeNull = repcap.SubframeNull.Default) \n
		Sets the PDCCH format. \n
			:param format_py: VAR| -1| 0| 1| 2| 3 VAR Enables full flexibility by the configuration of the downlink control information (DCI) format and content. -1 Proprietary format for legacy support. 0 | 1 | 2 | 3 One PDCCH is transmitted on one, two, four or eight CCEs
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
		"""
		param = Conversions.enum_scalar_to_str(format_py, enums.EutraPdccFmt2)
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:SUBF{subframeNull_cmd_val}:ENCC:PDCCh:FORMat {param}')

	# noinspection PyTypeChecker
	def get(self, subframeNull=repcap.SubframeNull.Default) -> enums.EutraPdccFmt2:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:[SUBF<ST0>]:ENCC:PDCCh:FORMat \n
		Snippet: value: enums.EutraPdccFmt2 = driver.source.bb.eutra.downlink.subf.encc.pdcch.formatPy.get(subframeNull = repcap.SubframeNull.Default) \n
		Sets the PDCCH format. \n
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:return: format_py: VAR| -1| 0| 1| 2| 3 VAR Enables full flexibility by the configuration of the downlink control information (DCI) format and content. -1 Proprietary format for legacy support. 0 | 1 | 2 | 3 One PDCCH is transmitted on one, two, four or eight CCEs"""
		subframeNull_cmd_val = self._cmd_group.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:SUBF{subframeNull_cmd_val}:ENCC:PDCCh:FORMat?')
		return Conversions.str_to_scalar_enum(response, enums.EutraPdccFmt2)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BoLengthCls:
	"""BoLength commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("boLength", core, parent)

	def set(self, bo_frame_len: int, commandBlock=repcap.CommandBlock.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NFC:CBLock<CH>:APGeneric:BOLength \n
		Snippet: driver.source.bb.nfc.cblock.apGeneric.boLength.set(bo_frame_len = 1, commandBlock = repcap.CommandBlock.Default) \n
		Sets the length of the first part of a bit oriented SDD frame. \n
			:param bo_frame_len: integer Range: 16 to 55
			:param commandBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')
		"""
		param = Conversions.decimal_value_to_str(bo_frame_len)
		commandBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(commandBlock, repcap.CommandBlock)
		self._core.io.write(f'SOURce<HwInstance>:BB:NFC:CBLock{commandBlock_cmd_val}:APGeneric:BOLength {param}')

	def get(self, commandBlock=repcap.CommandBlock.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:NFC:CBLock<CH>:APGeneric:BOLength \n
		Snippet: value: int = driver.source.bb.nfc.cblock.apGeneric.boLength.get(commandBlock = repcap.CommandBlock.Default) \n
		Sets the length of the first part of a bit oriented SDD frame. \n
			:param commandBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cblock')
			:return: bo_frame_len: integer Range: 16 to 55"""
		commandBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(commandBlock, repcap.CommandBlock)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NFC:CBLock{commandBlock_cmd_val}:APGeneric:BOLength?')
		return Conversions.str_to_int(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ChannelsCls:
	"""Channels commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("channels", core, parent)

	def get_max(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:SELection:CHANnels:MAX \n
		Snippet: value: int = driver.source.bb.gnss.sv.selection.channels.get_max() \n
		Queries the maximum number of GNSS channels. The number depends on the simulation capacity, see 'Channel budget'. \n
			:return: max_numb_channels: integer Range: 6 to 612
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:SV:SELection:CHANnels:MAX?')
		return Conversions.str_to_int(response)

	def set_max(self, max_numb_channels: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SV:SELection:CHANnels:MAX \n
		Snippet: driver.source.bb.gnss.sv.selection.channels.set_max(max_numb_channels = 1) \n
		Queries the maximum number of GNSS channels. The number depends on the simulation capacity, see 'Channel budget'. \n
			:param max_numb_channels: integer Range: 6 to 612
		"""
		param = Conversions.decimal_value_to_str(max_numb_channels)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SV:SELection:CHANnels:MAX {param}')



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MisuseCls:
	"""Misuse commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("misuse", core, parent)

	def set(self, misuse: bool, baseStation=repcap.BaseStation.Default, groupNull=repcap.GroupNull.Default, offset=repcap.Offset.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:C2K:BSTation<ST>:CGRoup<DI0>:COFFset<CH>:TPC:MISuse \n
		Snippet: driver.source.bb.c2K.bstation.cgroup.coffset.tpc.misuse.set(misuse = False, baseStation = repcap.BaseStation.Default, groupNull = repcap.GroupNull.Default, offset = repcap.Offset.Default) \n
		The command activates 'mis-' use of the power control bits of the selected F-DCCH or F- FCH for controlling the channel
		powers of these channels. Power control is available for sub channel types F-DCCH and F-FCH. F-DCCH is only generated for
		radio configurations 3, 4 and 5. The bit pattern (see commands BB:C2K:BSTation<n>:CGRoup<n>:COFFset<n>:TPC...) of the
		power control bits of each channel is used to control the channel power. A '1' leads to an increase of channel powers, a
		'0' to a reduction of channel powers. Channel power is limited to the range 0 dB to -80 dB. The step width of the change
		is defined with the command [:SOURce<hw>]:BB:C2K:BSTation<st>:CGRoup<di0>:COFFset<ch>:TPC:PSTep. For the traffic channels,
		this value is specific for the selected radio configuration. \n
			:param misuse: 1| ON| 0| OFF
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param groupNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cgroup')
			:param offset: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Coffset')
		"""
		param = Conversions.bool_to_str(misuse)
		baseStation_cmd_val = self._cmd_group.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		groupNull_cmd_val = self._cmd_group.get_repcap_cmd_value(groupNull, repcap.GroupNull)
		offset_cmd_val = self._cmd_group.get_repcap_cmd_value(offset, repcap.Offset)
		self._core.io.write(f'SOURce<HwInstance>:BB:C2K:BSTation{baseStation_cmd_val}:CGRoup{groupNull_cmd_val}:COFFset{offset_cmd_val}:TPC:MISuse {param}')

	def get(self, baseStation=repcap.BaseStation.Default, groupNull=repcap.GroupNull.Default, offset=repcap.Offset.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:C2K:BSTation<ST>:CGRoup<DI0>:COFFset<CH>:TPC:MISuse \n
		Snippet: value: bool = driver.source.bb.c2K.bstation.cgroup.coffset.tpc.misuse.get(baseStation = repcap.BaseStation.Default, groupNull = repcap.GroupNull.Default, offset = repcap.Offset.Default) \n
		The command activates 'mis-' use of the power control bits of the selected F-DCCH or F- FCH for controlling the channel
		powers of these channels. Power control is available for sub channel types F-DCCH and F-FCH. F-DCCH is only generated for
		radio configurations 3, 4 and 5. The bit pattern (see commands BB:C2K:BSTation<n>:CGRoup<n>:COFFset<n>:TPC...) of the
		power control bits of each channel is used to control the channel power. A '1' leads to an increase of channel powers, a
		'0' to a reduction of channel powers. Channel power is limited to the range 0 dB to -80 dB. The step width of the change
		is defined with the command [:SOURce<hw>]:BB:C2K:BSTation<st>:CGRoup<di0>:COFFset<ch>:TPC:PSTep. For the traffic channels,
		this value is specific for the selected radio configuration. \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param groupNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cgroup')
			:param offset: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Coffset')
			:return: misuse: 1| ON| 0| OFF"""
		baseStation_cmd_val = self._cmd_group.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		groupNull_cmd_val = self._cmd_group.get_repcap_cmd_value(groupNull, repcap.GroupNull)
		offset_cmd_val = self._cmd_group.get_repcap_cmd_value(offset, repcap.Offset)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:C2K:BSTation{baseStation_cmd_val}:CGRoup{groupNull_cmd_val}:COFFset{offset_cmd_val}:TPC:MISuse?')
		return Conversions.str_to_bool(response)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HsdpaCls:
	"""Hsdpa commands group definition. 25 total commands, 21 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("hsdpa", core, parent)

	@property
	def bpayload(self):
		"""bpayload commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bpayload'):
			from .Bpayload import BpayloadCls
			self._bpayload = BpayloadCls(self._core, self._cmd_group)
		return self._bpayload

	@property
	def crate(self):
		"""crate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_crate'):
			from .Crate import CrateCls
			self._crate = CrateCls(self._core, self._cmd_group)
		return self._crate

	@property
	def ctsCount(self):
		"""ctsCount commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ctsCount'):
			from .CtsCount import CtsCountCls
			self._ctsCount = CtsCountCls(self._core, self._cmd_group)
		return self._ctsCount

	@property
	def data(self):
		"""data commands group. 2 Sub-classes, 1 commands."""
		if not hasattr(self, '_data'):
			from .Data import DataCls
			self._data = DataCls(self._core, self._cmd_group)
		return self._data

	@property
	def harq(self):
		"""harq commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_harq'):
			from .Harq import HarqCls
			self._harq = HarqCls(self._core, self._cmd_group)
		return self._harq

	@property
	def mibt(self):
		"""mibt commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mibt'):
			from .Mibt import MibtCls
			self._mibt = MibtCls(self._core, self._cmd_group)
		return self._mibt

	@property
	def modulation(self):
		"""modulation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_modulation'):
			from .Modulation import ModulationCls
			self._modulation = ModulationCls(self._core, self._cmd_group)
		return self._modulation

	@property
	def ncbTti(self):
		"""ncbTti commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ncbTti'):
			from .NcbTti import NcbTtiCls
			self._ncbTti = NcbTtiCls(self._core, self._cmd_group)
		return self._ncbTti

	@property
	def rmc(self):
		"""rmc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rmc'):
			from .Rmc import RmcCls
			self._rmc = RmcCls(self._core, self._cmd_group)
		return self._rmc

	@property
	def rvParameter(self):
		"""rvParameter commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rvParameter'):
			from .RvParameter import RvParameterCls
			self._rvParameter = RvParameterCls(self._core, self._cmd_group)
		return self._rvParameter

	@property
	def rvSequence(self):
		"""rvSequence commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rvSequence'):
			from .RvSequence import RvSequenceCls
			self._rvSequence = RvSequenceCls(self._core, self._cmd_group)
		return self._rvSequence

	@property
	def scch(self):
		"""scch commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_scch'):
			from .Scch import ScchCls
			self._scch = ScchCls(self._core, self._cmd_group)
		return self._scch

	@property
	def sformat(self):
		"""sformat commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sformat'):
			from .Sformat import SformatCls
			self._sformat = SformatCls(self._core, self._cmd_group)
		return self._sformat

	@property
	def spattern(self):
		"""spattern commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_spattern'):
			from .Spattern import SpatternCls
			self._spattern = SpatternCls(self._core, self._cmd_group)
		return self._spattern

	@property
	def tbs(self):
		"""tbs commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_tbs'):
			from .Tbs import TbsCls
			self._tbs = TbsCls(self._core, self._cmd_group)
		return self._tbs

	@property
	def tsCount(self):
		"""tsCount commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tsCount'):
			from .TsCount import TsCountCls
			self._tsCount = TsCountCls(self._core, self._cmd_group)
		return self._tsCount

	@property
	def ttiDistance(self):
		"""ttiDistance commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ttiDistance'):
			from .TtiDistance import TtiDistanceCls
			self._ttiDistance = TtiDistanceCls(self._core, self._cmd_group)
		return self._ttiDistance

	@property
	def ttInterval(self):
		"""ttInterval commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ttInterval'):
			from .TtInterval import TtIntervalCls
			self._ttInterval = TtIntervalCls(self._core, self._cmd_group)
		return self._ttInterval

	@property
	def ueCategory(self):
		"""ueCategory commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ueCategory'):
			from .UeCategory import UeCategoryCls
			self._ueCategory = UeCategoryCls(self._core, self._cmd_group)
		return self._ueCategory

	@property
	def ueId(self):
		"""ueId commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ueId'):
			from .UeId import UeIdCls
			self._ueId = UeIdCls(self._core, self._cmd_group)
		return self._ueId

	@property
	def vibSize(self):
		"""vibSize commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_vibSize'):
			from .VibSize import VibSizeCls
			self._vibSize = VibSizeCls(self._core, self._cmd_group)
		return self._vibSize

	def clone(self) -> 'HsdpaCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = HsdpaCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class EmtcCls:
	"""Emtc commands group definition. 8 total commands, 8 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("emtc", core, parent)

	@property
	def celv(self):
		"""celv commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_celv'):
			from .Celv import CelvCls
			self._celv = CelvCls(self._core, self._cmd_group)
		return self._celv

	@property
	def dt(self):
		"""dt commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dt'):
			from .Dt import DtCls
			self._dt = DtCls(self._core, self._cmd_group)
		return self._dt

	@property
	def frIndex(self):
		"""frIndex commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_frIndex'):
			from .FrIndex import FrIndexCls
			self._frIndex = FrIndexCls(self._core, self._cmd_group)
		return self._frIndex

	@property
	def ncsConf(self):
		"""ncsConf commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ncsConf'):
			from .NcsConf import NcsConfCls
			self._ncsConf = NcsConfCls(self._core, self._cmd_group)
		return self._ncsConf

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import PowerCls
			self._power = PowerCls(self._core, self._cmd_group)
		return self._power

	@property
	def rsequence(self):
		"""rsequence commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rsequence'):
			from .Rsequence import RsequenceCls
			self._rsequence = RsequenceCls(self._core, self._cmd_group)
		return self._rsequence

	@property
	def sfStart(self):
		"""sfStart commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sfStart'):
			from .SfStart import SfStartCls
			self._sfStart = SfStartCls(self._core, self._cmd_group)
		return self._sfStart

	@property
	def sindex(self):
		"""sindex commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sindex'):
			from .Sindex import SindexCls
			self._sindex = SindexCls(self._core, self._cmd_group)
		return self._sindex

	def clone(self) -> 'EmtcCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = EmtcCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TdelayCls:
	"""Tdelay commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tdelay", core, parent)

	def set(self, tdelay: int, baseStation=repcap.BaseStation.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:TDELay \n
		Snippet: driver.source.bb.w3Gpp.bstation.tdelay.set(tdelay = 1, baseStation = repcap.BaseStation.Default) \n
		Adds a time shift for the selected base station compared to base station 1. \n
			:param tdelay: integer Range: 0 to 38400 , Unit: chip
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
		"""
		param = Conversions.decimal_value_to_str(tdelay)
		baseStation_cmd_val = self._cmd_group.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:TDELay {param}')

	def get(self, baseStation=repcap.BaseStation.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:TDELay \n
		Snippet: value: int = driver.source.bb.w3Gpp.bstation.tdelay.get(baseStation = repcap.BaseStation.Default) \n
		Adds a time shift for the selected base station compared to base station 1. \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:return: tdelay: integer Range: 0 to 38400 , Unit: chip"""
		baseStation_cmd_val = self._cmd_group.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:TDELay?')
		return Conversions.str_to_int(response)
